# R version 3.6.1 (2019-07-05)
# Perceptual span experiment: 2 Age(Older, Younger)*5 Window(N, W, WL1, WR1, WR2)

library(languageR)
library(lme4)
library(lattice)
library(MASS)
library(plyr) 

rm(list=ls())

datafile = read.csv(file.choose(), sep = ",", dec = ".")

colnames(datafile)
##################################################################

col.subject = 1      # specify which column your participant number is in
col.Stem = 2         # specify which column your itmes number is in
col.condition = 5     #specify which column contains your condition number(maximal condition number)

# choose dependent variable
measure = "SRT"

# add to dataframe
datafile$depvar = datafile[,measure]

###########################################################
# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$Participants)
datafile$Stem = as.factor(datafile$Items)
datafile$condition = as.factor(datafile$Age.Window)
datafile$Age = as.factor(datafile$Age)
datafile$Window = as.factor(datafile$Window)
datafile$Age.Window = as.factor(datafile$Age.Window)

#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

###############################################################################
#############################################################
# Log transform

# Do we need to log transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))

# If yes
datafile$depvar = log(datafile$depvar)

################################################
# 2*5analyses
################################################

# table of means for Age
(table1 <- ddply(datafile, .(Age), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

# table of means for Emotion
(table2 <- ddply(datafile, .(Window), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

# table of means for Age x Emotion
(table3 <- ddply(datafile, .(Age, Window), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))

#######################################
levels(datafile$Window)
levels(datafile$Age)
#######################################
contrasts(datafile$Age) <- contr.sdif(2) 

#next set the contrasts for the window in the following part

#next set the contrasts for the window in the following part
#####################################
contrast.matrix <- matrix(c(   
   0, -1, +1, 0, 0,        # W vs WL1
   0, -1, 0, +1, 0,        # W vs WR1
   0, 0, 0,-1, +1,         # WR1 vs WR2
  -1, 0, 0, 0, +1          # N vs WR2
), 5, 4,                

dimnames=list(c("N", "W", "WL1", "WR1", "WR2"), 
              c("W vs WL1", "W vs WR1","WR1 vs WR2","N vs WR2")))

# Perform some magic (needs to inverse it before assigning to the contrasts)
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 5, 4,
                              dimnames=list(c("N", "W", "WL1", "WR1", "WR2"), 
                                            c("W vs WL1", "W vs WR1","WR1 vs WR2","N vs WR2")))
(contrasts(datafile$Window) <- fractions(inv.contrast.matrix))


depvar.lmer1 = lmer(depvar ~ Age * Window  + (1+Window|Participants) + (1+Window|Items),datafile)
print(depvar.lmer1, corr = FALSE)

summary(depvar.lmer1, corr = FALSE)

##########################################

depvar.lmer1 = lmer(depvar ~ Age * Window  + (1+Window |Participants) + (1|Items),control=lmerControl (optimizer="bobyqa", optCtrl = list(maxfun = 1000000)), datafile)
summary(depvar.lmer1, corr = FALSE)


###############################################
# Investigate interactions between Age and Window

# What order are our levels in?
levels(datafile$Age.Window)

# Define our contrasts for AgeWindow
#when we set the matrix,we should depend on this levels(datafile$Age.Window) the sequences of the condition
###################################################

# Contrast matrix for AgeWindow
contrast.matrix <- matrix(c(   
  0, +1, -1, 0, 0, 0, 0, 0, 0, 0,       # Older W vs WL1
  0, +1, 0, -1, 0, 0, 0, 0, 0, 0,       # Older W vs WR1
  0, 0, 0, +1, -1, 0, 0, 0, 0, 0,       # Older WR1 vs WR2
  +1, 0, 0, 0, -1, 0, 0, 0, 0, 0,       # Older N vs WR2
 
  0, 0, 0, 0, 0, 0, +1, -1, 0, 0,       # Younger W vs WL1
  0, 0, 0, 0, 0, 0, +1, 0, -1, 0,       # Younger W vs WR1
  0, 0, 0, 0, 0, 0, 0, 0, +1, -1,       # Younger WR1 vs WR2
  0, 0, 0, 0, 0, +1, 0, 0, 0, -1        # Younger N vs WR2
), 10, 8,   
  dimnames=list(c("O_N", "O_W", "O_WL1","O_WR1","O_WR2", "Y_N", "Y_W","Y_WL1", "Y_WR1", "Y_WR2"), 
                c("O_WvsWL1", "O_WvsWR1","O_WR1vsWR2", "O_NvsWR2", "Y_WvsWL1", "Y_WvsWR1","Y_WR1vsWR2", "Y_NvsWR2")))

# Perform some magic (needs to inverse it before assigning to the contrasts)
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 10, 8,
                              dimnames=list(c("O_N", "O_W", "O_WL1","O_WR1","O_WR2", "Y_N", "Y_W","Y_WL1", "Y_WR1", "Y_WR2"), 
                                            c("O_WvsWL1", "O_WvsWR1","O_WR1vsWR2", "O_NvsWR2", "Y_WvsWL1", "Y_WvsWR1","Y_WR1vsWR2", "Y_NvsWR2")))
(contrasts(datafile$Age.Window) <- fractions(inv.contrast.matrix))

depvar.lmerAge.Window = lmer(depvar ~ Age.Window + (1+Window|Participants) + (1+Window|Items),  datafile)
summary(depvar.lmerAge.Window, corr = FALSE)
