# R version 3.6.1 (2019-07-05)
##bayes analsyis for sensitivity

library(BayesFactor) #version 0.9.12-4.2

rm(list=ls())

datafile = read.csv(file.choose(), sep = ",", dec = ".")

colnames(datafile)


# choose dependent variable
measure = "WordMin"

datafile$depvar = datafile[,measure]

############################
# Log transform

# Do we need to log transform?
qqnorm(datafile$depvar)
qqnorm(log(datafile$depvar))

# If yes
datafile$depvar = log(datafile$depvar)


#################################
## set parameters for analysis ##
# which method to use for obtaining the marginal likelihood,
# monte carlo integration (default) were used, but to reduce proporitonal error we've upped the iterations to 100,000
iterations <- 100000 

rscaleFixed <- 0.5    # scaling factor for g-priors for fixed effects

whichRandom <- c("Participants", "Items")  # specify random effects

##################################################
#example- 
q1<- subset(datafile, Window== "WR1" | Window== "WR2")
q1$Window<- droplevels(q1$Window)
q1$Window<- factor(q1$Window, levels=c("WR1", "WR2"))
contrasts(q1$Window)

q2<- subset(datafile, Window== "W" | Window== "WL1")
q2$Window<- droplevels(q2$Window)
q2$Window<- factor(q2$Window, levels=c("W", "WL1"))
contrasts(q2$Window)

q3<- subset(datafile, Window== "W" | Window== "WR1")
q3$Window<- droplevels(q3$Window)
q3$Window<- factor(q3$Window, levels=c("W", "WR1"))
contrasts(q3$Window)


q4<- subset(datafile, Window== "N" | Window== "WR2")
q4$Window<- droplevels(q4$Window)
q4$Window<- factor(q4$Window, levels=c("N", "WR2"))
contrasts(q4$Window)

## Bayes factor of full model against null, with pp and stim as random factors.

bfFull = lmBF (depvar ~ Age + Window + Age:Window + Participants + Items, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, q3)

bfMain = lmBF (depvar ~  Age + Window + Participants + Items, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, q3)


bf = bfFull/bfMain

bf

#####################################

priorRange<- c(0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8)

B<- NULL

for(i in 1:length(priorRange)){
  bfFull= lmBF (depvar ~ Age + Window + Age:Window + Participants + Items,
                whichRandom = whichRandom, rscaleFixed = priorRange[i],
                iterations = iterations, q2)
  
  bfMain= lmBF (depvar ~ Age + Window + Participants + Items, whichRandom = whichRandom,
                rscaleFixed = priorRange[i], iterations = iterations, q2)
  
  # extract bf
  B[i]<- extractBF(bfFull/bfMain)$bf
}


db<- data.frame(priorRange, B)

db


###Plot for the sensitivity analsyses
library(scales) # Version 0.5.0
library(ggplot2) # Version 2.2.1
rscaleFixed<- 0.5 # default 

Plot<- ggplot(data= db, aes(x=priorRange, y= B))+
  theme_bw() + theme(panel.grid.major = element_line(colour = "#BDBDBD", size=0.7),
                     axis.line = element_line(colour = "black", size=2),
                     panel.border = element_rect(colour = "black", size=1, fill = NA))+
  scale_y_continuous(breaks = pretty_breaks(n = 7))+
  geom_line(size=2)+ xlab("Prior scale")+ ylab("Bayes Factor")+
  theme(title=element_text(size=26), axis.title.x = element_text(size=26, face="bold"), 
        axis.title.y = element_text(size=26, face="bold"), axis.text=element_text(size=26), 
        panel.border = element_rect(linetype = "solid", colour = "black"), 
        legend.key = element_rect(colour = "#000000", size=1), plot.title = element_text(hjust = 0.5))


Plot<- Plot + geom_point(mapping=aes(x=rscaleFixed, y=db$B[which(db$priorRange==rscaleFixed)],
                                     shape=22), color="red", fill="red", size=8)+ 
  scale_shape_identity()+ 
  geom_text(mapping=aes(x=rscaleFixed+0.1, y= 0.12, label= "default prior"), size=8)

Plot
print(Plot)